Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1024)

Unified Diff: runtime/bin/dartutils.cc

Issue 16123036: Clean up dart:io exceptions. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 7 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/bin/dartutils.h ('k') | runtime/bin/directory.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/bin/dartutils.cc
diff --git a/runtime/bin/dartutils.cc b/runtime/bin/dartutils.cc
index fc9046942654246cd33e0bd4816867ac5d229c4c..375c6d5963fae93b8fc5bfb33f4413a742c9de74 100644
--- a/runtime/bin/dartutils.cc
+++ b/runtime/bin/dartutils.cc
@@ -760,10 +760,10 @@ Dart_Handle DartUtils::NewDartOSError(OSError* os_error) {
}
-Dart_Handle DartUtils::NewDartSocketIOException(const char* message,
- Dart_Handle os_error) {
- // Create a dart:io SocketIOException object.
- Dart_Handle clazz = GetDartClass(kIOLibURL, "SocketIOException");
+Dart_Handle DartUtils::NewDartSocketException(const char* message,
+ Dart_Handle os_error) {
+ // Create a dart:io SocketException object.
+ Dart_Handle clazz = GetDartClass(kIOLibURL, "SocketException");
Dart_Handle args[2];
args[0] = NewString(message);
args[1] = os_error;
« no previous file with comments | « runtime/bin/dartutils.h ('k') | runtime/bin/directory.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698